/***************************************************************************
                          serial2doc.cpp  -  description
                             -------------------
    begin                : Ut feb 18 14:21:20 CET 2003
    copyright            : (C) 2003 by Ondrej Krško
    email                : ondrej.krsko@zoznam.sk
 ***************************************************************************/

// include files for Qt
#include <qdir.h>
#include <qwidget.h>

// include files for KDE
#include <klocale.h>
#include <kmessagebox.h>
#include <kio/job.h>
#include <kio/netaccess.h>

// application specific includes
#include "serial2doc.h"
#include "serial2.h"
#include "serial2view.h"

QList<Serial2View> *Serial2Doc::pViewList = 0L;

Serial2Doc::Serial2Doc(QWidget *parent, const char *name) : QObject(parent, name)
{
  if(!pViewList)
  {
    pViewList = new QList<Serial2View>();
  }

  pViewList->setAutoDelete(true);
}

Serial2Doc::~Serial2Doc()
{
}

int Serial2Doc::penWidth()
{
  return pen.width();
}

void Serial2Doc::addView(Serial2View *view)
{
  pViewList->append(view);
}

void Serial2Doc::removeView(Serial2View *view)
{
  pViewList->remove(view);
}
void Serial2Doc::setURL(const KURL &url)
{
  doc_url=url;
}

const KURL& Serial2Doc::URL() const
{
  return doc_url;
}

void Serial2Doc::slotUpdateAllViews(Serial2View *sender)
{
  Serial2View *w;
  if(pViewList)
  {
    for(w=pViewList->first(); w!=0; w=pViewList->next())
    {
      if(w!=sender)
        w->repaint();
    }
  }

}

bool Serial2Doc::saveModified()
{
  bool completed=true;

  if(modified)
  {
    Serial2App *win=(Serial2App *) parent();
    int want_save = KMessageBox::warningYesNoCancel(win,
                                         i18n("The current file has been modified.\n"
                                              "Do you want to save it?"),
                                         i18n("Warning"));
    switch(want_save)
    {
      case KMessageBox::Yes:
           if (doc_url.fileName() == i18n("Untitled"))
           {
             win->slotFileSaveAs();
           }
           else
           {
             saveDocument(URL());
       	   };

       	   deleteContents();
           completed=true;
           break;

      case KMessageBox::No:
           setModified(false);
           deleteContents();
           completed=true;
           break;

      case KMessageBox::Cancel:
           completed=false;
           break;

      default:
           completed=false;
           break;
    }
  }

  return completed;
}

void Serial2Doc::closeDocument()
{
  deleteContents();
}

bool Serial2Doc::newDocument()
{
  size=QSize(300,200);
  buffer.resize(size);
  buffer.fill( Qt::white );
  pen=QPen( Qt::blue, 2 );

  modified=false;
  doc_url.setFileName(i18n("Untitled"));

  return true;
}

bool Serial2Doc::openDocument(const KURL& url, const char *format /*=0*/)
{
  QString tmpfile;
  KIO::NetAccess::download( url, tmpfile );
  /////////////////////////////////////////////////
  // TODO: Add your document opening code here
  /////////////////////////////////////////////////

  KIO::NetAccess::removeTempFile( tmpfile );

  modified=false;
  return true;
}

bool Serial2Doc::saveDocument(const KURL& url, const char *format /*=0*/)
{
  /////////////////////////////////////////////////
  // TODO: Add your document saving code here
  /////////////////////////////////////////////////

  modified=false;
  return true;
}

void Serial2Doc::deleteContents()
{
  /////////////////////////////////////////////////
  // TODO: Add implementation to delete the document contents
  /////////////////////////////////////////////////

}
